<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en">
<context>
    <name>AccessCert</name>
    <message>
        <source>Error downloading server access certificate!
%1</source>
        <translation>Error downloading server access certificate!
%1</translation>
    </message>
    <message>
        <source>Empty result!</source>
        <translation>Empty result!</translation>
    </message>
    <message>
        <source>Error parsing server access certificate result!</source>
        <translation>Error parsing server access certificate result!</translation>
    </message>
    <message>
        <source>Error reading server access certificate - empty content!</source>
        <translation>Error reading server access certificate - empty content!</translation>
    </message>
    <message>
        <source>Failed to save server access certificate file to %1!
%2</source>
        <translation>Failed to save server access certificate file to %1!
%2</translation>
    </message>
    <message>
        <source>Server access certificate</source>
        <translation>Server access certificate</translation>
    </message>
    <message>
        <source>Did not find any server access certificate!
Start downloading?</source>
        <translation>Did not find any server access certificate!
Start downloading?</translation>
    </message>
    <message>
        <source>Failed to read server access certificate!
Start downloading?</source>
        <translation>Failed to read server access certificate!
Start downloading?</translation>
    </message>
    <message>
        <source>Server access certificate password is not valid!
Start downloading?</source>
        <translation>Server access certificate password is not valid!
Start downloading?</translation>
    </message>
    <message>
        <source>Server access certificate is not valid!
Start downloading?</source>
        <translation>Server access certificate is not valid!
Start downloading?</translation>
    </message>
    <message>
        <source>Server access certificate is about to expire!
Start downloading?</source>
        <translation>Server access certificate is about to expire!
Start downloading?</translation>
    </message>
</context>
<context>
    <name>DigiDoc</name>
    <message>
        <source>Container is not open</source>
        <translation>Container is not open</translation>
    </message>
    <message>
        <source>Cannot add files to signed container</source>
        <translation>Cannot add files to signed container</translation>
    </message>
    <message>
        <source>Missing document</source>
        <translation>Missing document</translation>
    </message>
    <message>
        <source>Cannot add signature to empty container</source>
        <translation>Cannot add signature to empty container</translation>
    </message>
    <message>
        <source>Missing signature</source>
        <translation>Missing signature</translation>
    </message>
    <message>
        <source>PIN Incorrect</source>
        <translation>PIN Incorrect</translation>
    </message>
    <message>
        <source>PIN Locked</source>
        <translation>PIN Locked</translation>
    </message>
    <message>
        <source>PIN Login failed</source>
        <translation>PIN Login failed</translation>
    </message>
    <message>
        <source>Certificate status revoked</source>
        <translation>Certificate status revoked</translation>
    </message>
    <message>
        <source>Certificate status unknown</source>
        <translation>Certificate status unknown</translation>
    </message>
    <message>
        <source>Check your computer time</source>
        <translation>Check your computer time</translation>
    </message>
    <message>
        <source>An error occurred while opening the document.&lt;br /&gt;%1</source>
        <translation>An error occurred while opening the document.&lt;br /&gt;%1</translation>
    </message>
    <message>
        <source>Server access certificate is required</source>
        <translation>Server access certificate is required</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Settings</source>
        <translation>Settings</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Next</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Signature</translation>
    </message>
    <message>
        <source>Role</source>
        <translation>Role</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Resolution</translation>
    </message>
    <message>
        <source>City</source>
        <translation>City</translation>
    </message>
    <message>
        <source>State</source>
        <translation>State</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>Country</translation>
    </message>
    <message>
        <source>Zip</source>
        <translation>Zip</translation>
    </message>
    <message>
        <source>Sign</source>
        <translation>Sign</translation>
    </message>
    <message>
        <source>Add signature</source>
        <translation>Add signature</translation>
    </message>
    <message>
        <source>Save container</source>
        <translation>Save container</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Remove</translation>
    </message>
    <message>
        <source>Keep</source>
        <translation>Keep</translation>
    </message>
    <message>
        <source>Open container</source>
        <translation>Open container</translation>
    </message>
    <message>
        <source>Select folder where files will be stored</source>
        <translation>Select folder where files will be stored</translation>
    </message>
    <message>
        <source>This container is signed by you</source>
        <translation>This container is signed by you</translation>
    </message>
    <message>
        <source>You have not signed this container</source>
        <translation>You have not signed this container</translation>
    </message>
    <message>
        <source>Container is unsigned</source>
        <translation>Container is unsigned</translation>
    </message>
    <message>
        <source>Select documents</source>
        <translation>Select documents</translation>
    </message>
    <message>
        <source>Skip this intro</source>
        <translation>Skip this intro</translation>
    </message>
    <message>
        <source>Save file</source>
        <translation>Save file</translation>
    </message>
    <message>
        <source>Failed to start process &apos;qdigidoccrypto&apos;</source>
        <translation>Failed to start process &apos;Digidoc Crypto&apos;</translation>
    </message>
    <message>
        <source>Failed to start process &apos;qesteidutil&apos;</source>
        <translation>Failed to start process &apos;qesteidutil&apos;</translation>
    </message>
    <message>
        <source>Documents (*.bdoc *.ddoc)</source>
        <translation>Documents (*.bdoc *.ddoc)</translation>
    </message>
    <message>
        <source>No card in reader</source>
        <translation>No card in reader</translation>
    </message>
    <message>
        <source>I want to:</source>
        <translation>I want to:</translation>
    </message>
    <message>
        <source>Sign documents</source>
        <translation>Sign documents</translation>
    </message>
    <message>
        <source>View signed document content</source>
        <translation>View signed document content</translation>
    </message>
    <message>
        <source>Container content:</source>
        <translation>Container content:</translation>
    </message>
    <message>
        <source>Container:</source>
        <translation>Container:</translation>
    </message>
    <message>
        <source>Use Mobile ID</source>
        <translation>Use Mobile ID</translation>
    </message>
    <message>
        <source>Use ID-card</source>
        <translation>Use ID-card</translation>
    </message>
    <message>
        <source>This container is </source>
        <translation>This container is </translation>
    </message>
    <message>
        <source>&lt;a href=&quot;saveAs&quot;&gt;Save files to disk&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;saveAs&quot;&gt;Save files to disk&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;email&quot;&gt;Send container to email&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;email&quot;&gt;Send container to email&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;print&quot;&gt;Print summary&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;print&quot;&gt;Print summary&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;browse&quot;&gt;Browse container location&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;browse&quot;&gt;Browse container location&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Arial, Liberation Sans&apos;; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Roll ...&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Arial, Liberation Sans&apos;; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Roll ...&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Arial, Liberation Sans&apos;; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Resolution ...&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Arial, Liberation Sans&apos;; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Resolution ...&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>File already in container</source>
        <translation>File already in container</translation>
    </message>
    <message>
        <source>%1&lt;br /&gt;already in container, ovewrite?</source>
        <translation>%1&lt;br /&gt;already in container, ovewrite?</translation>
    </message>
    <message>
        <source>Loading data</source>
        <translation>Loading data</translation>
    </message>
    <message>
        <source>Mobile number:</source>
        <translation>Mobile number:</translation>
    </message>
    <message>
        <source>Personal code:</source>
        <translation>Personal code:</translation>
    </message>
    <message>
        <source>Encrypt files for secure transfer</source>
        <translation>Encrypt files for secure transfer</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;
&lt;/head&gt;&lt;body&gt;
&lt;p style=&quot; font: 12px &apos;Arial,Liberation Sans&apos;;&quot;&gt;
Digital signing.&lt;br /&gt;&lt;br /&gt;
Digital signing is equal to physical signing. To sign a document you need an ID-card with a valid and usable signature certificate.&lt;br /&gt;&lt;br /&gt;
Signing is done via PIN2 code&lt;br /&gt;&lt;br /&gt;
Also an active internet connection is needed.&lt;/p&gt;
&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;
&lt;/head&gt;&lt;body&gt;
&lt;p style=&quot; font: 12px &apos;Arial,Liberation Sans&apos;;&quot;&gt;
Digital signing.&lt;br /&gt;&lt;br /&gt;
Digital signing is equal to physical signing. To sign a document you need an ID-card with a valid and usable signature certificate.&lt;br /&gt;&lt;br /&gt;
Signing is done via PIN2 code&lt;br /&gt;&lt;br /&gt;
Also an active internet connection is needed.&lt;/p&gt;
&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;addFile&quot;&gt;Add file&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;addFile&quot;&gt;Add file&lt;/a&gt;</translation>
    </message>
    <message>
        <source>%1 already exists.&lt;br /&gt;Do you want replace it?</source>
        <translation>%1 already exists.&lt;br /&gt;Do you want replace it?</translation>
    </message>
    <message>
        <source>Personal code is not valid</source>
        <translation>Personal code is not valid</translation>
    </message>
    <message>
        <source>NB! Test signature</source>
        <translation>NB! Test signature</translation>
    </message>
    <message>
        <source>NB! Invalid signature</source>
        <translation>NB! Invalid signature</translation>
    </message>
    <message>
        <source>You don't have sufficient privileges to write this file into folder %1</source>
        <translation>You don't have sufficient privileges to write this file into folder %1</translation>
    </message>
    <message>
        <source>Documents (*.bdoc *.BDOC *.ddoc *.DDOC)</source>
        <translation>Documents (*.bdoc *.BDOC *.ddoc *.DDOC)</translation>
    </message>
    <message>
        <source>DigiDoc3 client</source>
        <translation>DigiDoc3 client</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;File</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Close</translation>
    </message>
    <message numerus="yes">
        <source>Signature(s)</source>
        <translation>
            <numerusform>Signature</numerusform>
            <numerusform>Signatures</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>You added %n file(s) to container, but these are not signed yet.
Should I keep unsigned documents or remove these?</source>
        <translation>
            <numerusform>You added %n file to container, but these are not signed yet.
Should I keep unsigned documents or remove these?</numerusform>
            <numerusform>You added %n files to container, but these are not signed yet.
Should I keep unsigned documents or remove these?</numerusform>
        </translation>
    </message>
    <message>
        <source>You can not add files to signed document. Remove all signatures before adding files.</source>
        <translation>You can not add files to signed document. Remove all signatures before adding files.</translation>
    </message>
    <message>
        <source>Sign certificate is not valid</source>
        <translation>Sign certificate is not valid</translation>
    </message>
</context>
<context>
    <name>MobileDialog</name>
    <message>
        <source>Signing in process</source>
        <translation>Signing in process</translation>
    </message>
    <message>
        <source>Request accepted</source>
        <translation>Request accepted</translation>
    </message>
    <message>
        <source>Request timeout</source>
        <translation>Request timeout</translation>
    </message>
    <message>
        <source>User denied or cancelled</source>
        <translation>User denied or cancelled</translation>
    </message>
    <message>
        <source>Got signature</source>
        <translation>Got signature</translation>
    </message>
    <message>
        <source>Request pending</source>
        <translation>Request pending</translation>
    </message>
    <message>
        <source>Mobile-ID not ready, try again later</source>
        <translation>Mobile-ID not ready, try again later</translation>
    </message>
    <message>
        <source>Phone absent</source>
        <translation>Phone absent</translation>
    </message>
    <message>
        <source>Request sending error</source>
        <translation>Request sending error</translation>
    </message>
    <message>
        <source>SIM error</source>
        <translation>SIM error</translation>
    </message>
    <message>
        <source>Service internal error</source>
        <translation>Service internal error</translation>
    </message>
    <message>
        <source>Signing with Mobile-ID</source>
        <translation>Signing with Mobile-ID</translation>
    </message>
    <message>
        <source>Control code: %1</source>
        <translation>Control code: %1</translation>
    </message>
    <message>
        <source>%v sec</source>
        <translation>%v sec</translation>
    </message>
    <message>
        <source>Connecting to SK server failed!
Please check your internet connection.</source>
        <translation>Connecting to SK server failed!
Please check your internet connection.</translation>
    </message>
    <message>
        <source>User is not a Mobile-ID client</source>
        <translation>User is not a Mobile-ID client</translation>
    </message>
    <message>
        <source>ID and phone number do not match</source>
        <translation>ID and phone number do not match</translation>
    </message>
    <message>
        <source>Empty HTTP result</source>
        <translation>Empty HTTP result</translation>
    </message>
    <message>
        <source>Failed to parse XML document</source>
        <translation>Failed to parse XML document</translation>
    </message>
    <message>
        <source>Not allowed to use OCSP service!
Please check your server access sertificate.</source>
        <translation>Not allowed to use OCSP service!
Please check your server access sertificate.</translation>
    </message>
    <message>
        <source>Sign</source>
        <translation>Sign</translation>
    </message>
    <message>
        <source>Certificate status unknown</source>
        <translation>Certificate status unknown</translation>
    </message>
</context>
<context>
    <name>PrintSheet</name>
    <message>
        <source>SIGNED FILES</source>
        <translation>SIGNED FILES</translation>
    </message>
    <message>
        <source>FILE NAME</source>
        <translation>FILE NAME</translation>
    </message>
    <message>
        <source>FILE SIZE</source>
        <translation>FILE SIZE</translation>
    </message>
    <message>
        <source>SIGNERS</source>
        <translation>SIGNERS</translation>
    </message>
    <message>
        <source>NAME</source>
        <translation>NAME</translation>
    </message>
    <message>
        <source>PERSONAL CODE</source>
        <translation>PERSONAL CODE</translation>
    </message>
    <message>
        <source>TIME</source>
        <translation>TIME</translation>
    </message>
    <message>
        <source>SIGNATURE</source>
        <translation>SIGNATURE</translation>
    </message>
    <message>
        <source>NOTES</source>
        <translation>NOTES</translation>
    </message>
    <message>
        <source>VALIDITY CONFIRMATION SHEET</source>
        <translation>VALIDITY CONFIRMATION SHEET</translation>
    </message>
    <message>
        <source>NO.</source>
        <translation>NO.</translation>
    </message>
    <message>
        <source>VALIDITY OF SIGNATURE</source>
        <translation>VALIDITY OF SIGNATURE</translation>
    </message>
    <message>
        <source>VALID</source>
        <translation>VALID</translation>
    </message>
    <message>
        <source>NOT VALID</source>
        <translation>NOT VALID</translation>
    </message>
    <message>
        <source>ROLE / RESOLUTION</source>
        <translation>ROLE / RESOLUTION</translation>
    </message>
    <message>
        <source>PLACE OF CONFIRMATION (CITY, STATE, ZIP, COUNTRY)</source>
        <translation>PLACE OF CONFIRMATION (CITY, STATE, ZIP, COUNTRY)</translation>
    </message>
    <message>
        <source>SERIAL NUMBER OF CERTIFICATE</source>
        <translation>SERIAL NUMBER OF CERTIFICATE</translation>
    </message>
    <message>
        <source>ISSUER OF CERTIFICATE</source>
        <translation>ISSUER OF CERTIFICATE</translation>
    </message>
    <message>
        <source>HASH VALUE OF ISSUER&apos;S PUBLIC KEY</source>
        <translation>HASH VALUE OF ISSUER&apos;S PUBLIC KEY</translation>
    </message>
    <message>
        <source>HASH VALUE OF VALIDITY CONFIRMATION (OCSP RESPONSE)</source>
        <translation>HASH VALUE OF VALIDITY CONFIRMATION (OCSP RESPONSE)</translation>
    </message>
    <message>
        <source>The print out of files listed in the section &lt;b&gt;&quot;Signed Files&quot;&lt;/b&gt; are inseparable part of this Validity Confirmation Sheet.</source>
        <translation>The print out of files listed in the section &lt;b&gt;&quot;Signed Files&quot;&lt;/b&gt; are inseparable part of this Validity Confirmation Sheet.</translation>
    </message>
    <message>
        <source>COMPANY</source>
        <translation>COMPANY</translation>
    </message>
    <message>
        <source>REGISTER CODE</source>
        <translation>REGISTER CODE</translation>
    </message>
    <message>
        <source>UNKNOWN</source>
        <translation>UNKNOWN</translation>
    </message>
</context>
<context>
    <name>QSigner</name>
    <message>
        <source>Failed to load PKCS#11 module</source>
        <translation>Failed to load PKCS#11 module</translation>
    </message>
    <message>
        <source>PIN acquisition canceled.</source>
        <translation>PIN acquisition canceled.</translation>
    </message>
    <message>
        <source>Signing certificate is not selected.</source>
        <translation>Signing certificate is not selected.</translation>
    </message>
    <message>
        <source>Failed to login token</source>
        <translation>Wrong PIN</translation>
    </message>
    <message>
        <source>PIN Incorrect</source>
        <translation>PIN Incorrect</translation>
    </message>
    <message>
        <source>PIN Locked</source>
        <translation>PIN Locked. Please use ID-card utility for PIN opening!</translation>
    </message>
    <message>
        <source>Failed to sign document</source>
        <translation>Failed to sign document</translation>
    </message>
    <message>
        <source>Sign certificate is not selected</source>
        <translation>Sign certificate is not selected</translation>
    </message>
</context>
<context>
    <name>RegisterP12</name>
    <message>
        <source>No OCSP PKCS#12 certificate selected</source>
        <translation>No OCSP PKCS#12 certificate selected</translation>
    </message>
    <message>
        <source>Failed to copy file</source>
        <translation>Failed to copy file</translation>
    </message>
    <message>
        <source>Select PKCS#12 certificate</source>
        <translation>Select PKCS#12 certificate</translation>
    </message>
    <message>
        <source>PKCS#12 Certificates (*.p12 *.p12d)</source>
        <translation>PKCS#12 Certificates (*.p12 *.p12d)</translation>
    </message>
    <message>
        <source>OCSP PKCS#12 certificate installer</source>
        <translation>OCSP PKCS#12 certificate installer</translation>
    </message>
    <message>
        <source>OCSP PKCS#12 certificate</source>
        <translation>OCSP PKCS#12 certificate</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>OCSP PKCS#12 server access certificate is available at&lt;br /&gt;
&lt;a href=&quot;http://www.sk.ee/getaccess/?lang=eng&quot;&gt;http://www.sk.ee/toend/&lt;/a&gt;</source>
        <translation>Confirmation of validity of the server reference access can be obtained from the SK web page&lt;br /&gt;
&lt;a href=&quot;http://www.sk.ee/getaccess/?lang=eng&quot;&gt;http://www.sk.ee/toend/&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Settings</translation>
    </message>
    <message>
        <source>Container default location</source>
        <translation>Container default location</translation>
    </message>
    <message>
        <source>Role</source>
        <translation>Role</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Resolution</translation>
    </message>
    <message>
        <source>City</source>
        <translation>City</translation>
    </message>
    <message>
        <source>State</source>
        <translation>State</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>Country</translation>
    </message>
    <message>
        <source>Zip</source>
        <translation>Zip</translation>
    </message>
    <message>
        <source>Select folder</source>
        <translation>Select folder</translation>
    </message>
    <message>
        <source>Show signing intro</source>
        <translation>Show signing intro</translation>
    </message>
    <message>
        <source>Same folder</source>
        <translation>Same folder</translation>
    </message>
    <message>
        <source>Ask container name</source>
        <translation>Ask container name</translation>
    </message>
    <message>
        <source>Default file type:</source>
        <translation>Default file type:</translation>
    </message>
    <message>
        <source>Save last insert role and resolution</source>
        <translation>Save last insert role and resolution</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Signature</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <source>Host</source>
        <translation>Host</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Select PKCS#12 certificate</source>
        <translation>Select PKCS#12 certificate</translation>
    </message>
    <message>
        <source>PKCS#12 Certificates (*.p12 *.p12d)</source>
        <translation>PKCS#12 Certificates (*.p12 *.p12d)</translation>
    </message>
    <message>
        <source>OCSP PKCS#12 certificate</source>
        <translation>OCSP PKCS#12 certificate</translation>
    </message>
    <message>
        <source>Certificate</source>
        <translation>Certificate</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Username</translation>
    </message>
    <message>
        <source>If you change file format from .bdoc to .ddoc or vise versa, opened file will not change.</source>
        <translation>If you change file format from .bdoc to .ddoc or vise versa, opened file will not change.</translation>
    </message>
    <message>
        <source>Show certificate</source>
        <translation>Show certificate</translation>
    </message>
</context>
<context>
    <name>SignatureDialog</name>
    <message>
        <source>Signing time</source>
        <translation>Signing time</translation>
    </message>
    <message>
        <source>Signature type</source>
        <translation>Signature type</translation>
    </message>
    <message>
        <source>Signature format</source>
        <translation>Signature format</translation>
    </message>
    <message>
        <source>Signed file count</source>
        <translation>Signed file count</translation>
    </message>
    <message>
        <source>Certificate serialnumber</source>
        <translation>Certificate serialnumber</translation>
    </message>
    <message>
        <source>Certificate valid at</source>
        <translation>Certificate valid at</translation>
    </message>
    <message>
        <source>Certificate valid until</source>
        <translation>Certificate valid until</translation>
    </message>
    <message>
        <source>Certificate issuer</source>
        <translation>Certificate issuer</translation>
    </message>
    <message>
        <source>Signer</source>
        <translation>Signer</translation>
    </message>
    <message>
        <source>Signer location</source>
        <translation>Signer location</translation>
    </message>
    <message>
        <source>City</source>
        <translation>City</translation>
    </message>
    <message>
        <source>State</source>
        <translation>State</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>Country</translation>
    </message>
    <message>
        <source>Zip</source>
        <translation>Zip</translation>
    </message>
    <message>
        <source>Role / resolution</source>
        <translation>Role / resolution</translation>
    </message>
    <message>
        <source>Show certificate</source>
        <translation>Show certificate</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Signature</translation>
    </message>
    <message>
        <source>Attribute</source>
        <translation>Attribute</translation>
    </message>
    <message>
        <source>Value</source>
        <translation>Value</translation>
    </message>
    <message>
        <source>OCSP</source>
        <translation>OCSP</translation>
    </message>
    <message>
        <source>Signature is valid</source>
        <translation>Signature is valid</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Unknown error</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Time</translation>
    </message>
    <message>
        <source>Hash value of validity confirmation</source>
        <translation>Hash value of validity confirmation</translation>
    </message>
    <message>
        <source>Signature is not valid</source>
        <translation>Signature is not valid</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <source>Signature status unknown</source>
        <translation>Signature status unknown</translation>
    </message>
</context>
<context>
    <name>SignatureWidget</name>
    <message>
        <source>valid</source>
        <translation>valid</translation>
    </message>
    <message>
        <source>not valid</source>
        <translation>not valid</translation>
    </message>
    <message>
        <source>Show details</source>
        <translation>Show details</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Remove</translation>
    </message>
    <message>
        <source>Signed on</source>
        <translation>Signed on</translation>
    </message>
    <message>
        <source>Signature is</source>
        <translation>Signature is</translation>
    </message>
    <message>
        <source>time</source>
        <translation>time</translation>
    </message>
    <message>
        <source>Test signature</source>
        <translation>Test signature</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>unknown</translation>
    </message>
    <message>
        <source>Remove signature %1</source>
        <translation>Remove signature %1</translation>
    </message>
</context>
<context>
    <name>TreeWidget</name>
    <message>
        <source>Save</source>
        <translation>Save</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Remove</translation>
    </message>
    <message>
        <source>Save file</source>
        <translation>Save file</translation>
    </message>
</context>
</TS>
